# Ubuntu Testing Automation Harness
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Test get_file function."""


import os.path
import unittest

from mock import patch

from utah.getfile import get_file


class TestGetFile(unittest.TestCase):

    """Test file retrieval functionality."""

    def test_tilde_path(self):
        """Verify we expand a ~-based path."""
        path = '~'
        final_path = os.path.expanduser(path)
        with patch('utah.getfile.urlretrieve') as urlretrieve, \
                patch('utah.getfile.dldisplay') as dldisplay:
            get_file(path)
            urlretrieve.assert_called_with(final_path,
                                           reporthook=dldisplay().dldisplay)

    def test_local_path(self):
        """Verify we pass a local path through correctly."""
        path = '/dev/null'
        with patch('utah.getfile.urlretrieve') as urlretrieve, \
                patch('utah.getfile.dldisplay') as dldisplay:
            get_file(path)
            urlretrieve.assert_called_with(path,
                                           reporthook=dldisplay().dldisplay)

    def test_url_path(self):
        """Verify we rely on url_argument for a remote path."""
        path = 'http://example.com/spam.run'
        localpath = '/tmp/spam.run'
        with patch('utah.getfile.url_argument') as url_argument, \
                patch('utah.getfile.urlretrieve') as urlretrieve, \
                patch('utah.getfile.dldisplay') as dldisplay:
            url_argument.return_value = localpath
            get_file(path)
            urlretrieve.assert_called_with(localpath,
                                           reporthook=dldisplay().dldisplay)
