# Ubuntu Testing Automation Harness
# Copyright 2012 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Test the dev pseudo-VCS interface."""


import os
import shutil
import unittest

from utah.client.common import run_cmd
from utah.client.vcs import DevHandler


DEV_TEST_REPO = "/tmp/utahdevtest"


def setUp():
    """Create a local directory for testing."""
    # should fail if the repo already exists.
    os.mkdir(DEV_TEST_REPO)

    run_cmd("touch test.py", cwd=DEV_TEST_REPO)


def tearDown():
    """Remove the test repo."""
    # We should only ever get here if the repo was created in setUp().
    shutil.rmtree(DEV_TEST_REPO)


class TestDevHandler(unittest.TestCase):

    """Test the dev pseudo-VCS handler."""

    def test_init(self):
        """Test the initial setup."""
        repo = DEV_TEST_REPO
        dev = DevHandler(repo=repo)

        self.assertIsNotNone(dev)
        self.assertEqual(dev.repo, repo)
        self.assertEqual(dev.get_command, "cp -r {} .".format(repo))
        self.assertEqual(dev.rev_command, "echo 'DEVELOPMENT'")

    def test_dev_get(self):
        """Test copying files."""
        repo = DEV_TEST_REPO
        dest = "utah-dev"
        dev = DevHandler(repo=repo, destination=dest)
        directory = "/tmp"
        path = os.path.join(directory, dest)

        self.assertFalse(os.path.exists(path), path)

        result = dev.get(directory=directory)
        self.assertEqual(result['returncode'], 0)

        self.assertTrue(os.path.exists(path), path)
        shutil.rmtree(path)

    def test_dev_revision(self):
        """Test fake revision gathering support."""
        repo = DEV_TEST_REPO
        dest = "utah-dev"
        dev = DevHandler(repo=repo, destination=dest)
        directory = "/tmp"
        path = os.path.join(directory, dest)

        self.assertFalse(os.path.exists(path))
        result = dev.get(directory=directory)
        self.assertEqual(result['returncode'], 0)
        self.assertTrue(os.path.exists(path))

        result = dev.revision(directory=path)

        shutil.rmtree(path)
        self.assertEqual(result['returncode'], 0)
