# Ubuntu Testing Automation Harness
# Copyright 2012 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""This module provides a method to fetch arbitrary resources."""


import logging
import os.path

from urllib import urlretrieve

from utah.config import config
from utah.exceptions import UTAHException
from utah.url import url_argument


class dldisplay(object):

    """Class to provide persistence for percent data for dldisplay."""

    def __init__(self):
        self.percent = 0

    def dldisplay(self, blocks, size, total):
        """Log download information (i.e., as a urllib callback).

        :param blocks: Number of blocks downloaded
        :type blocks: int
        :param size: Size of blocks downloaded
        :type size: int
        :param total: Total size of download
        :type size: int

        """
        read = blocks * size
        percent = 100 * read / total
        if percent >= self.percent:
            logging.info('File %s%% downloaded', percent)
            self.percent += config.dlpercentincrement
        logging.debug('%s read, %s%% of %s total', read, percent, total)


def get_file(url):
    """Fetch an arbitrary http, lp, bzr, or local resource.

    :returns: Local path to the fetched resource
    :rtype: str

    """
    if url.startswith('~'):
        url = os.path.expanduser(url)
    url = url_argument(url)
    dl = dldisplay()
    try:
        resource = urlretrieve(url, reporthook=dl.dldisplay)
        return resource[0]
    except IOError as err:
        raise UTAHException(
            'IOError when copying {}: {}'.format(url, err), external=True)
